@@ -1,6 +1,7 @@
 from unittest.mock import MagicMock, Mock
 
 from jaseci.svc import MailService
+from jaseci.svc.mail import MAIL_CONFIG
 from jaseci.utils.test_core import CoreTest
 
 
@@ -10,6 +11,7 @@ class MailLibTest(CoreTest):
     fixture_src = __file__
 
     def __init__(self, *args, **kwargs):
+        MAIL_CONFIG["enabled"] = True
         MailService.connect = MagicMock(return_value=Mock())
         super(MailLibTest, self).__init__(*args, **kwargs)
 
