@@ -5,6 +5,9 @@ Utility for all runtime interaction with variables in different scopes
 """
 from jaseci.utils.id_list import IdList
 from jaseci.jac.machine.jac_value import JacValue
+from jaseci.actions.live_actions import get_global_actions
+
+global_action_sets = None
 
 
 class JacScope:
@@ -13,16 +16,17 @@ class JacScope:
         self.local_scope = {}
         self.has_obj = has_obj if has_obj else self
         self.context = {}
-        self.action_sets = action_sets + [
-            IdList(parent, in_list=parent._h.global_action_list, auto_save=False)
-        ]
+        self.action_sets = action_sets
         self.setup_actions()
 
     def setup_actions(self):
+        global global_action_sets
+        if global_action_sets is None:
+            global_action_sets = self.group_actions(get_global_actions())
         allactions = []
         for i in self.action_sets:
             allactions += i.obj_list()
-        self.action_sets = {}
+        self.action_sets = global_action_sets
         for i in allactions:
             self.add_action(i)
 
@@ -36,6 +40,19 @@ class JacScope:
         else:
             self.action_sets[group] = act
 
+    def group_actions(self, act_list):
+        action_sets = {}
+        for act in act_list:
+            group = act.name.split(".")[0]
+            if "." in act.name:
+                if group not in action_sets.keys():
+                    action_sets[group] = {}
+                action = act.name.split(".")[1]
+                action_sets[group][action] = act
+            else:
+                action_sets[group] = act
+        return action_sets
+
     def set_agent_refs(self, cur_node, cur_walker):
         self.local_scope["here"] = cur_node
         self.local_scope["visitor"] = cur_walker
